

# ZETUP



[![](http://www.gnu.org/graphics/lgplv3-88x31.png)](
  https://gnu.org/licenses/lgpl.html)
[![](https://img.shields.io/pypi/pyversions/zetup.svg)](
  https://python.org)



[![](https://img.shields.io/pypi/v/zetup.svg)](
  https://pypi.python.org/pypi/zetup)
[![](https://img.shields.io/pypi/dd/zetup.svg)](
  https://pypi.python.org/pypi/zetup)



[![](https://travis-ci.org/zimmermanncode/zetup.svg?branch=master)](
  https://travis-ci.org/userzimmermann/zetup.py)
[![Build status](https://ci.appveyor.com/api/projects/status/3wm8jnisoft5x7qr?svg=true)](
  https://ci.appveyor.com/project/userzimmermann/zetup-py)



## Zimmermann's Extensible Tools for Unified Project setups



* https://bitbucket.org/zimmermanncode/zetup
* https://github.com/zimmermanncode/zetup
* https://gitlab.com/zimmermanncode/zetup
* https://www.openhub.net/p/python-zetup

